@@ -286,11 +286,16 @@ public:
         /// \operators
         /// @{
 
-        bool operator== (const Frame &a)
+        bool operator== (const Frame &a) const
         {
-            return (address () == a.address ());
+            return (level () == a.level ()
+                    && function_name () == a.function_name ()
+                    && file_name () == a.file_name ()
+                    && library () == a.library ());
         }
 
+        bool operator!= (const Frame &a) const {return !(operator== (a));}
+
         /// @}
         /// \name accessors
 
@@ -1108,6 +1113,9 @@ public:
 
     virtual bool busy () const = 0;
 
+    virtual void set_non_persistent_debugger_path
+                (const UString &a_full_path) = 0;
+
     virtual const UString& get_debugger_full_path () const  = 0;
 
     virtual void set_solib_prefix_path (const UString &a_name) = 0;
