@@ -22,6 +22,7 @@
  *
  *See COPYRIGHT file copyright information.
  */
+#include "config.h"
 #include <sstream>
 #include <algorithm>
 #include <gtkmm/treeview.h>
@@ -720,8 +721,11 @@ struct CallStack::Priv {
         if (a_frames.size () >= nb_frames_expansion_chunk) {
             store_iter = store->append ();
             UString msg;
-            msg.printf (_("(Click here to see the next %d rows of the "
-                          "call stack)"),
+            msg.printf (ngettext ("(Click here to see the next %d row of the "
+                                  "call stack",
+                                  "(Click here to see the next %d rows of the "
+                                  "call stack)",
+                                  nb_frames_expansion_chunk),
                         nb_frames_expansion_chunk);
             (*store_iter)[columns ().frame_index_caption] = "...";
             (*store_iter)[columns ().location] = msg;
