@@ -45,24 +45,25 @@ private:
     Priv ();
 public:
     Gtk::Dialog &dialog;
-    Glib::RefPtr<Gnome::Glade::Xml> glade;
+    Glib::RefPtr<Gtk::Builder> gtkbuilder;
     IDebuggerSafePtr debugger;
     IVarListWalkerSafePtr global_variables_walker_list;
 
     IWorkbench &workbench;
-    VarsTreeViewSafePtr tree_view;
+    VarsTreeView* tree_view;
     Glib::RefPtr<Gtk::TreeStore> tree_store;
     Gtk::TreeModel::iterator cur_selected_row;
     SafePtr<Gtk::Menu> contextual_menu;
     UString previous_function_name;
 
     Priv (Gtk::Dialog &a_dialog,
-          const Glib::RefPtr<Gnome::Glade::Xml> &a_glade,
+          const Glib::RefPtr<Gtk::Builder> &a_gtkbuilder,
           IDebuggerSafePtr &a_debugger,
           IWorkbench &a_workbench) :
         dialog (a_dialog),
-        glade (a_glade),
-        workbench (a_workbench)
+        gtkbuilder (a_gtkbuilder),
+        workbench (a_workbench),
+        tree_view (0)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
 
@@ -79,7 +80,7 @@ public:
     void build_dialog ()
     {
         Gtk::Box *box =
-            ui_utils::get_widget_from_glade<Gtk::Box> (glade,
+            ui_utils::get_widget_from_gtkbuilder<Gtk::Box> (gtkbuilder,
                                                        "inspectorwidgetbox");
         THROW_IF_FAIL (box);
         Gtk::ScrolledWindow *scr = Gtk::manage (new Gtk::ScrolledWindow);
@@ -315,10 +316,10 @@ GlobalVarsInspectorDialog::GlobalVarsInspectorDialog
                                             (const UString &a_root_path,
         IDebuggerSafePtr &a_debugger, IWorkbench &a_workbench) :
     Dialog (a_root_path,
-            "globalvarsinspector.glade",
+            "globalvarsinspector.ui",
             "globalvarsinspector")
 {
-    m_priv.reset (new Priv (widget (), glade (), a_debugger, a_workbench));
+    m_priv.reset (new Priv (widget (), gtkbuilder (), a_debugger, a_workbench));
 }
 
 GlobalVarsInspectorDialog::~GlobalVarsInspectorDialog ()
