@@ -1,12 +1,14 @@
+#include "config.h"
 #include <iostream>
 #include <boost/test/minimal.hpp>
 #include <glibmm.h>
 #include "common/nmv-initializer.h"
 #include "common/nmv-safe-ptr-utils.h"
 #include "nmv-i-debugger.h"
+#include "nmv-debugger-utils.h"
 
 using namespace nemiver;
-using namespace nemiver::common ;
+using namespace nemiver::common;
 
 Glib::RefPtr<Glib::MainLoop> loop =
     Glib::MainLoop::create (Glib::MainContext::get_default ());
@@ -18,7 +20,7 @@ void
 on_engine_died_signal ()
 {
     MESSAGE ("engine died");
-    loop->quit () ;
+    loop->quit ();
 }
 
 void
@@ -29,14 +31,14 @@ on_program_finished_signal ()
 }
 
 void
-on_breakpoints_set_signal (const std::map<int, IDebugger::BreakPoint> &a_breaks,
+on_breakpoints_set_signal (const std::map<int, IDebugger::Breakpoint> &a_breaks,
                            const UString &a_cookie)
 {
     if (a_cookie.empty ()) {}
 
     MESSAGE ("breakpoints set:");
-    std::map<int, IDebugger::BreakPoint>::const_iterator it;
-    for (it = a_breaks.begin () ; it != a_breaks.end () ; ++it) {
+    std::map<int, IDebugger::Breakpoint>::const_iterator it;
+    for (it = a_breaks.begin (); it != a_breaks.end () ; ++it) {
         MESSAGE ("<break><num>" << it->first <<"</num><line>"
                  << it->second.file_name () << ":" << it->second.line ()
                  << "</line></break>");
@@ -80,9 +82,8 @@ test_main (int, char **)
 
     THROW_IF_FAIL (loop);
 
-    DynamicModuleManager module_manager;
     IDebuggerSafePtr debugger =
-        module_manager.load_iface<IDebugger> ("gdbengine", "IDebugger");
+        debugger_utils::load_debugger_iface_with_confmgr ();
 
     debugger->set_event_loop_context (loop->get_context ());
 
@@ -94,20 +95,21 @@ test_main (int, char **)
     debugger->program_finished_signal ().connect
                                             (&on_program_finished_signal);
 
-    debugger->breakpoints_set_signal ().connect
-                                            (&on_breakpoints_set_signal);
+    debugger->breakpoints_list_signal ().connect
+        (&on_breakpoints_set_signal);
 
     debugger->stopped_signal ().connect
                             (sigc::bind (&on_stopped_signal, debugger));
 
     std::vector<UString> args, source_search_dir;
     source_search_dir.push_back (".");
-    debugger->load_program ("fooprog", args, ".", source_search_dir);
+    debugger->load_program ("fooprog", args, ".",
+                            source_search_dir, "", false);
     debugger->set_breakpoint ("main");
     debugger->set_breakpoint ("func1");
     debugger->run ();
 
-    loop->run () ;
+    loop->run ();
 
     NEMIVER_CATCH_NOX
 
